---
// @ts-check
import Layout from '../layouts/Layout.astro';
import '../styles/global.css';
import axios from 'axios';
import logo from '../assets/images/logo.png?url';  // Imagen por defecto en caso de error

// Obtener las variables de entorno
const API_URL = import.meta.env.VITE_API_URL;
const TOKEN = import.meta.env.VITE_JWT_TOKEN;

console.log(API_URL, TOKEN)

const fetchSiteData = async () => {
  try {
    const timestamp = new Date().getTime(); // Agrega un timestamp para evitar cachés
    const response = await axios.get(`${API_URL}/settings?_=${timestamp}`, {
      headers: {
        Authorization: `Bearer ${TOKEN}`, // Incluye el token JWT en los headers
      },
    });

    console.log('API Response:', response.data);

    return {
      title: response.data.title || 'Título no disponible',
      description: response.data.description || 'Descripción no disponible',
      logo: response.data.logo || logo,
    };
  } catch (error) {
    console.error('Error fetching site data:', error);
    return { title: 'Título no disponible', description: 'Descripción no disponible', logo: logo };
  }
};

// Obtener los datos del sitio
const siteData = await fetchSiteData();
---

<Layout title="Adsiona Commerce">
  <main class="size-full flex flex-col text-white items-center justify-center">
    <img src={siteData.logo} alt="Logo" class="w-48 h-auto mb-4" />
    <p>Título: {siteData.title}</p>
    <p>Descripción: {siteData.description}</p>
  </main>
</Layout>
